API
***

This part of the documentation lists the full API reference of all public
classes and functions.

.. currentmodule:: signalyzer

Signal Traces
=============

Trace
-----

.. autoclass:: Trace
   :members:

vectorize
~~~~~~~~~

.. autofunction:: vectorize

Traces
------

.. autoclass:: Traces
   :members:

VectorTraces
------------

.. autoclass:: VectorTraces
   :members:

polar
~~~~~

.. autofunction:: polar

StatisticsTraces
----------------

.. autoclass:: StatisticsTraces
   :members:

MovingAverageTraces
-------------------

.. autoclass:: MovingAverageTraces
   :members:

SetTraces
---------

.. autoclass:: SetTraces
   :members:

combine
~~~~~~~

.. autofunction:: combine


SlewRateLimiterTraces
---------------------

.. autoclass:: SlewRateLimiterTraces
   :members:


ExponentialSmoothingTraces
--------------------------

.. autoclass:: ExponentialSmoothingTraces
   :members:


LinearRegressionTraces
----------------------

.. autoclass:: LinearRegressionTraces
   :members:


Representations
===============

2D-Point
--------

.. autoclass:: Point2D
   :members:

3D-Point
--------

.. autoclass:: Point3D
   :members:

Vector
------

.. autoclass:: Vector
   :members:

2D-State
--------

.. autoclass:: State2D
   :members:

3D-State
--------

.. autoclass:: State3D
   :members:


Signal Processing
=================

Statistics
----------

.. autoclass:: Statistics
   :members:

Slew-Rate Limiter
-----------------

.. autoclass:: SlewRateLimiter
   :members:

Exponential Smoothing
---------------------

.. autoclass:: ExponentialSmoothing
   :members:

Linear Regression
-----------------

.. autoclass:: LinearRegression
   :members:

Filtering
---------

.. autoclass:: IIRFilter
   :members:


State Machines
==============

Statemachine
------------

.. autoclass:: Statemachine
   :members:


Converters
==========

as_traces
---------

.. autofunction:: as_traces
